/*
 * Copyright 2012 Emptoris, an IBM Company. All rights reserved.
 * EMPTORIS/IBM PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.emptoris.framework.utility;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.List;
import java.util.Locale;

/**
 * ArrayHelper
 * 
 * @author David Jesurum
 */
public class Utility
{
    public static <E> E[] append(E[] array, E item)
    {
        if (item == null)
        {
            return array;
        }
        int count = (array == null) ? 0 : array.length;
        E[] ret = (E[])new Object[count + 1];
        if (count > 0) {
            System.arraycopy(array, 0, ret, 0, count);
        }
        ret[count] = item;
        return ret;
    }

    /**
     * Convert an Array of Strings into a List of Strings
     * @param array
     * @return
     */
    public static List<String> convert(String[] array)
    {
        if (array == null)
        {
            return null;
        }
        List<String> list = new ArrayList<String>(); 
        for (String item : array)
        {
            list.add(item);
        }
        return list;
    }
    
    /**
     * Convert a List of String into an Array of Strings
     * @param list
     * @return
     */
    public static String[] convert(List<String> list)
    {
        int count = (list == null) ? 0 : list.size();
        String[] array = new String[count];
        for (int i = 0; i < count; i++)
        {
            array[i] = list.get(i);
        }
        return array;
    }
    
    /**
     * Convert a Calendar to a Date
     * @param c
     * @return
     */
    public static Date convert(Calendar c)
    {
        if (c == null)
        {
            return null;
        }
        return c.getTime();
    }
    
    /**
     * Convert a Date to a Calendar
     * @param d
     * @return
     */
    public static Calendar convert(Date d)
    {
        if (d == null)
        {
            return null;
        }
        Calendar c = new GregorianCalendar();
        c.setTime(d);
        return c;
    }
    
    /**
     * Convert a Locale to a String
     * @param l
     * @return
     */
    public static String convert(Locale l)
    {
        if (l == null)
        {
            return null;
        }
        return l.toString();
    }
    
    /**
     * Convert a String to a Locale
     * @param s
     * @return
     */
    public static Locale convert(String s)
    {
        if (s != null && s.length() >= 2)
        {
            String languageCode = s.substring(0, 2);
            if (s.length() < 5)
            {
                return new Locale(languageCode);
            }
            String countryCode = s.substring(3, 5);
            return new Locale(languageCode, countryCode);
        }
        return null;
    }
}
