/**
 * 
 */
package com.emptoris.vsm.sync.dto;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;

/**
 * @author rbadvelu
 *
 */
public class BaseDTO implements Serializable
{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	
	private Long id;						// VSM Internal Id
	private Long parentId;					// VSM Internal Parent Id;
	private String vsmId; 					// Master VSM Id
	private String parentVsmId;				// Parent Master VSM Id
	private String dataSource; 				// Data Source name
	private String dataSourceAppId; 		// Data Source specific application Id
	private String dataSourceAppParentId;	// Data Source specific application parent Id
	private List<CustomAttribute> customAttributes; // User Define attributes
    private String status;                  // The status of the record, such as Mapped, Unmapped, etc.
	private String action;                 // The action taken on the object. 
	private List<String> dataSourceVisibility; // A list of data sources that this DTO should be visible.
    private Locale defaultLocale;           // Default locale used by this DTO.
    private String createdBy;               // uuid of creator
    private Date createdOn;                 // date DTO entity was created
    private String updatedBy;               // uuid of user updating DTO entity
    private Date updatedOn;                 // date DTO entity was updated
	
	/**
	 * @return the id
	 */
	public Long getId()
	{
		return id;
	}

	/**
	 * @param id the id to set
	 */
	public void setId(Long id)
	{
		this.id = id;
	}

	/**
	 * @return the parentId
	 */
	public Long getParentId()
	{
		return parentId;
	}

	/**
	 * @param parentId the parentId to set
	 */
	public void setParentId(Long parentId)
	{
		this.parentId = parentId;
	}

	/**
	 * @return the vsmId
	 */
	public String getVsmId()
	{
		return vsmId;
	}

	/**
	 * @param vsmId the vsmId to set
	 */
	public void setVsmId(String vsmId)
	{
		this.vsmId = vsmId;
	}

	/**
	 * @return the parentVsmId
	 */
	public String getParentVsmId()
	{
		return parentVsmId;
	}

	/**
	 * @param parentVsmId the parentVsmId to set
	 */
	public void setParentVsmId(String parentVsmId)
	{
		this.parentVsmId = parentVsmId;
	}

	/**
	 * @return the dataSource
	 */
	public String getDataSource()
	{
		return dataSource;
	}

	/**
	 * @param dataSource the dataSource to set
	 */
	public void setDataSource(String dataSource)
	{
		this.dataSource = dataSource;
	}

	/**
	 * @return the dataSourceAppId
	 */
	public String getDataSourceAppId()
	{
		return dataSourceAppId;
	}

	/**
	 * @param dataSourceAppId the dataSourceAppId to set
	 */
	public void setDataSourceAppId(String dataSourceAppId)
	{
		this.dataSourceAppId = dataSourceAppId;
	}

	/**
	 * @return the dataSourceAppParentId
	 */
	public String getDataSourceAppParentId()
	{
		return dataSourceAppParentId;
	}

	/**
	 * @param dataSourceAppParentId the dataSourceAppParentId to set
	 */
	public void setDataSourceAppParentId(String dataSourceAppParentId)
	{
		this.dataSourceAppParentId = dataSourceAppParentId;
	}

	/**
	 * @return the customAttributes
	 */
	public List<CustomAttribute> getCustomAttributes()
	{
		if (customAttributes == null )
		{
			customAttributes = new ArrayList<CustomAttribute>();
		}
		return customAttributes;
	}

	/**
	 * @param customAttributes the customAttributes to set
	 */
	public void setCustomAttributes(List<CustomAttribute> customAttributes)
	{
		this.customAttributes = customAttributes;
	}
	
	/**
	 * Add custom attribute
	 * 
	 * @param customAttribute
	 */
	public void addCustomAttribute(CustomAttribute customAttribute)
	{
		getCustomAttributes().add(customAttribute);
	}
	
	/**
	 * Get custom attribute
	 * 
	 * @param index
	 * @return CustomAttribute
	 */
	public CustomAttribute getCustomAttribute(int index)
	{
		return getCustomAttributes().get(index);
	}

   /**
     * @return the status
     */
    public String getStatus() {
        return status;
    }

    /**
     * @param status the status to set
     */
    public void setStatus(String status) {
        this.status = status;
    }

    /**
     * @return the action taken on the corresponding data object.
     */
    public String getAction()
    {
        return action;
    }

    /**
     * @param action The action taken on the corresponding data object. 
     *  Default is null, which is insert/update.  
     */
    public void setAction(String action)
    {
        this.action = action;
    }

    /**
     * @return A list of data sources that this DTO should be visible in.
     */
    public List<String> getDataSourceVisibility()
    {
        return dataSourceVisibility;
    }

    /**
     * @param Set the list of data sources that this DTO should be visible in.
     */
    public void setDataSourceVisibility(List<String> dataSourceVisibility)
    {
        this.dataSourceVisibility = dataSourceVisibility;
    }

    /**
     * @return the defaultLocale
     */
    public Locale getDefaultLocale()
    {
        return defaultLocale;
    }

    /**
     * @param defaultLocale the defaultLocale to set
     */
    public void setDefaultLocale(Locale defaultLocale)
    {
        this.defaultLocale = defaultLocale;
    }

    public String getCreatedBy()
    {
        return createdBy;
    }

    public void setCreatedBy(String createdBy)
    {
        this.createdBy = createdBy;
    }

    public Date getCreatedOn()
    {
        return createdOn;
    }

    public void setCreatedOn(Date createdOn)
    {
        this.createdOn = createdOn;
    }

    public String getUpdatedBy()
    {
        return updatedBy;
    }

    public void setUpdatedBy(String updatedBy)
    {
        this.updatedBy = updatedBy;
    }

    public Date getUpdatedOn()
    {
        return updatedOn;
    }

    public void setUpdatedOn(Date updatedOn)
    {
        this.updatedOn = updatedOn;
    }

}
