package com.emptoris.vsm.sync.dto;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author rbadvelu
 *
 * Helper class for synchronizing the supplier organization / external party
 * data between VSM, Gateway and Emptoris suite of applications such as Sourcing, Contracts, etc.
 */
public class SupplierOrganizationDTO extends BaseDTO {
	/**
	 *
	 */
	private static final long serialVersionUID = 1L;

	private String mergedVsmId; // Golden master supplier Id if the supplier is merged with another master supplier
	private String companyName;		// Supplier Company Name
	private String masterCompanyName; // Supplier 
	private String legalName;	// Supplier legal name 
	private String businessDescription;  // Supplier Business description
	private String businessType; // Supplier Business Type
	private String website; // The web site.
	private String email; // The email address.
	private String currencyCode; // Supplier default currency code
	private UserDTO primaryContact; // Supplier	primary contact
	private String regionVsmId; // VSM Region Master ID
	
	private String narrativeDescription;
	private Integer numberOfEmployees;
	private Date dateEstablished;
	private Date deadDate;
	private String deadStatus;

	private String federalTaxId;
	private String dunsNumber;
	private String naicsCode;
	private String sicCode;
	private String bvdNumber;
	private String vatNumber;
	private String equifaxNumber;
	private Integer equifaxRating;
	
	// Map of external Id code, external Id value such as SAP/ERP Number
	private Map<String, String> externalIdentifiers;

	// Additional addresses, phone numbers and contacts
	private List<Phone> phoneNumbers;
	private List<Address> addresses;
	
    // Category linkage
    private List<Linkage> approvedCategories;
    // Region Linkage
    private List<Linkage> regions;
    // Linking status - mastered, unmastered.
    private String linkingStatus;
    
    // Ownership Classification 
    private String ownershipCitizenship; // Value must be set to Country ISO code
	private String ownershipGender;
	private String ownershipEthnicity;
	private Boolean ownershipDisabled;
	private Boolean ownershipVeteran;

	// Financial details
	private Double annualSales;
	private Integer fiscalYearEnd;
	private String stockExchange;
	private String stockSymbol;
	private Boolean taxExmpt;
	private String w9Name;
	private String w9BusinessName;
	
	private Boolean approved;
	
	private Long duplicateSupplierId;
	
	private Boolean primarySource;
	
	public SupplierOrganizationDTO() {

	}

	/**
	 * @return the mergedVsmId
	 */
	public String getMergedVsmId() {
		return mergedVsmId;
	}

	/**
	 * @param mergedVsmId the mergedVsmId to set
	 */
	public void setMergedVsmId(String mergedVsmId) {
		this.mergedVsmId = mergedVsmId;
	}


	/**
	 * @return the companyName
	 */
	public String getCompanyName()
	{
		return companyName;
	}

	/**
	 * @param companyName the companyName to set
	 */
	public void setCompanyName(String companyName)
	{
		this.companyName = companyName;
	}

	/**
	 * @return the masterCompanyName
	 */
	public String getMasterCompanyName()
	{
		return masterCompanyName;
	}

	/**
	 * @param masterCompanyName the masterCompanyName to set
	 */
	public void setMasterCompanyName(String masterCompanyName)
	{
		this.masterCompanyName = masterCompanyName;
	}

	/**
	 * @return the legalName
	 */
	public String getLegalName() {
		return legalName;
	}

	/**
	 * @param legalName the legalName to set
	 */
	public void setLegalName(String legalName) {
		this.legalName = legalName;
	}

	/**
	 * @return the businessDescription
	 */
	public String getBusinessDescription() {
		return businessDescription;
	}
	/**
	 * @param businessDescription the businessDescription to set
	 */
	public void setBusinessDescription(String businessDescription) {
		this.businessDescription = businessDescription;
	}
	/**
	 * @return the businessType
	 */
	public String getBusinessType() {
		return businessType;
	}
	/**
	 * @param businessType the businessType to set
	 */
	public void setBusinessType(String businessType) {
		this.businessType = businessType;
	}
	/**
	 * @return the website
	 */
	public String getWebsite() {
		return website;
	}

	/**
	 * @param website the website to set
	 */
	public void setWebsite(String website) {
		this.website = website;
	}

	/**
     * @return the email
     */
    public String getEmail()
    {
        return email;
    }

    /**
     * @param email the email to set
     */
    public void setEmail(String email)
    {
        this.email = email;
    }

    /**
	 * @return the currencyCode
	 */
	public String getCurrencyCode() {
		return currencyCode;
	}

	/**
	 * @param currencyCode the currencyCode to set
	 */
	public void setCurrencyCode(String currencyCode) {
		this.currencyCode = currencyCode;
	}

	/**
	 * @return the regionVsmId
	 */
	public String getRegionVsmId() {
		return regionVsmId;
	}

	/**
	 * @param regionVsmId the regionVsmId to set
	 */
	public void setRegionVsmId(String regionVsmId) {
		this.regionVsmId = regionVsmId;
	}

	/**
	 * @return the federalTaxId
	 */
	public String getFederalTaxId() {
		return federalTaxId;
	}

	/**
	 * @param federalTaxId the federalTaxId to set
	 */
	public void setFederalTaxId(String federalTaxId) {
		this.federalTaxId = federalTaxId;
	}

	/**
	 * @return the dunsNumber
	 */
	public String getDunsNumber() {
		return dunsNumber;
	}

	/**
	 * @param dunsNumber the dunsNumber to set
	 */
	public void setDunsNumber(String dunsNumber) {
		this.dunsNumber = dunsNumber;
	}

	/**
	 * @return the naicsCode
	 */
	public String getNaicsCode() {
		return naicsCode;
	}

	/**
	 * @param naicsCode the naicsCode to set
	 */
	public void setNaicsCode(String naicsCode) {
		this.naicsCode = naicsCode;
	}

	/**
	 * @return the sicCode
	 */
	public String getSicCode() {
		return sicCode;
	}

	/**
	 * @param sicCode the sicCode to set
	 */
	public void setSicCode(String sicCode) {
		this.sicCode = sicCode;
	}

	/**
	 * @return the bvdNumber
	 */
	public String getBvdNumber() {
		return bvdNumber;
	}

	/**
	 * @param bvdNumber the bvdNumber to set
	 */
	public void setBvdNumber(String bvdNumber) {
		this.bvdNumber = bvdNumber;
	}

	/**
	 * @return the vatNumber
	 */
	public String getVatNumber() {
		return vatNumber;
	}

	/**
	 * @param vatNumber the vatNumber to set
	 */
	public void setVatNumber(String vatNumber) {
		this.vatNumber = vatNumber;
	}

	/**
	 * @return the equifaxNumber
	 */
	public String getEquifaxNumber() {
		return equifaxNumber;
	}

	/**
	 * @param equifaxNumber the equifaxNumber to set
	 */
	public void setEquifaxNumber(String equifaxNumber) {
		this.equifaxNumber = equifaxNumber;
	}


    /**
	 * @return the primaryContact
	 */
	public UserDTO getPrimaryContact() {
		return primaryContact;
	}
	/**
	 * @param primaryContact the primaryContact to set
	 */
	public void setPrimaryContact(UserDTO primaryContact) {
		this.primaryContact = primaryContact;
	}

	/**
	 * @return the externalIdentifiers
	 */
	public Map<String, String> getExternalIdentifiers() {
		if (externalIdentifiers == null)
		{
			externalIdentifiers = new HashMap<String,String>();
		}
		return externalIdentifiers;
	}

	/**
	 * @param externalIdentifiers the externalIdentifiers to set
	 */
	public void setExternalIdentifiers(Map<String, String> externalIdentifiers) {
		this.externalIdentifiers = externalIdentifiers;
	}
	/**
	 * @param code
	 * @param value
	 */
	public void addExternalIdentifier(String code, String value) {
		getExternalIdentifiers().put(code, value);
	}
	/**
	 * @return the phoneNumbers
	 */
	public List<Phone> getPhoneNumbers() {
		if (phoneNumbers == null)
		{
			phoneNumbers = new ArrayList<Phone>();
		}
		return phoneNumbers;
	}
	/**
	 * @param phoneNumbers the phoneNumbers to set
	 */
	public void setPhoneNumbers(List<Phone> phoneNumbers) {
		this.phoneNumbers = phoneNumbers;
	}
	/**
	 * @param phone
	 */
	public void addPhoneNumber(Phone phone) {
		getPhoneNumbers().add(phone);
	}
	/**
	 * @return the addresses
	 */
	public List<Address> getAddresses() {
		if (addresses == null)
		{
			addresses = new ArrayList<Address>();
		}
		return  addresses;
	}
	/**
	 * @param addresses the addresses to set
	 */
	public void setAddresses(List<Address> addresses) {
		this.addresses = addresses;
	}
	/**
	 * 
	 * @param address
	 */
	public void addAddress(Address address) {
		getAddresses().add(address);
	}

    /**
     * Get the approved categories. 
     * @return The list of categories indicated by Linkage objects.
     */
    public List<Linkage> getApprovedCategories()
    {
    	if (approvedCategories == null)
    	{
    		approvedCategories = new ArrayList<Linkage>();
    	}
        return approvedCategories;
    }
    /**
     * Add approved category linkage
     * 
     * @param categoryLinkage
     */
    public void addApprovedCategory(Linkage categoryLinkage)
    {
    	getApprovedCategories().add(categoryLinkage);
    }
    /**
     * @param categories The list of approved categories.
     */
    public void setApprovedCategories(List<Linkage> categories) {
        this.approvedCategories = categories;
    }

    /**
     * @return the regions
     */
    public List<Linkage> getRegions()
    {
    	if (regions == null)
    	{
    		regions = new ArrayList<Linkage>();
    	}
        return regions;
    }

    /**
     * @param regions the regions to set
     */
    public void setRegions(List<Linkage> regions)
    {
        this.regions = regions;
    }

    /**
     * Add region linkage
     * 
     * @param regionLinkage
     */
    public void addRegion(Linkage regionLinkage)
    {
    	getRegions().add(regionLinkage);
    }

	/**
	 * @return the narrativeDescription
	 */
	public String getNarrativeDescription()
	{
		return narrativeDescription;
	}

	/**
	 * @param narrativeDescription the narrativeDescription to set
	 */
	public void setNarrativeDescription(String narrativeDescription)
	{
		this.narrativeDescription = narrativeDescription;
	}

	/**
	 * @return the numberOfEmployees
	 */
	public Integer getNumberOfEmployees()
	{
		return numberOfEmployees;
	}

	/**
	 * @param numberOfEmployees the numberOfEmployees to set
	 */
	public void setNumberOfEmployees(Integer numberOfEmployees)
	{
		this.numberOfEmployees = numberOfEmployees;
	}

	/**
	 * @return the dateEstablished
	 */
	public Date getDateEstablished()
	{
		return dateEstablished;
	}

	/**
	 * @param dateEstablished the dateEstablished to set
	 */
	public void setDateEstablished(Date dateEstablished)
	{
		this.dateEstablished = dateEstablished;
	}

	/**
	 * @return the deadDate
	 */
	public Date getDeadDate()
	{
		return deadDate;
	}

	/**
	 * @param deadDate the deadDate to set
	 */
	public void setDeadDate(Date deadDate)
	{
		this.deadDate = deadDate;
	}

	/**
	 * @return the deadStatus
	 */
	public String getDeadStatus()
	{
		return deadStatus;
	}

	/**
	 * @param deadStatus the deadStatus to set
	 */
	public void setDeadStatus(String deadStatus)
	{
		this.deadStatus = deadStatus;
	}

	/**
	 * @return the equifaxRating
	 */
	public Integer getEquifaxRating()
	{
		return equifaxRating;
	}

	/**
	 * @param equifaxRating the equifaxRating to set
	 */
	public void setEquifaxRating(Integer equifaxRating)
	{
		this.equifaxRating = equifaxRating;
	}

	/**
	 * @return the ownershipCitizenship
	 */
	public String getOwnershipCitizenship()
	{
		return ownershipCitizenship;
	}

	/**
	 * @param ownershipCitizenship the ownershipCitizenship to set
	 */
	public void setOwnershipCitizenship(String ownershipCitizenship)
	{
		this.ownershipCitizenship = ownershipCitizenship;
	}

	/**
	 * @return the ownershipGender
	 */
	public String getOwnershipGender()
	{
		return ownershipGender;
	}

	/**
	 * @param ownershipGender the ownershipGender to set
	 */
	public void setOwnershipGender(String ownershipGender)
	{
		this.ownershipGender = ownershipGender;
	}

	/**
	 * @return the ownershipEthnicity
	 */
	public String getOwnershipEthnicity()
	{
		return ownershipEthnicity;
	}

	/**
	 * @param ownershipEthnicity the ownershipEthnicity to set
	 */
	public void setOwnershipEthnicity(String ownershipEthnicity)
	{
		this.ownershipEthnicity = ownershipEthnicity;
	}

	/**
	 * @return the ownershipDisabled
	 */
	public Boolean getOwnershipDisabled()
	{
		return ownershipDisabled;
	}

	/**
	 * @param ownershipDisabled the ownershipDisabled to set
	 */
	public void setOwnershipDisabled(Boolean ownershipDisabled)
	{
		this.ownershipDisabled = ownershipDisabled;
	}

	/**
	 * @return the ownershipVeteran
	 */
	public Boolean getOwnershipVeteran()
	{
		return ownershipVeteran;
	}

	/**
	 * @param ownershipVeteran the ownershipVeteran to set
	 */
	public void setOwnershipVeteran(Boolean ownershipVeteran)
	{
		this.ownershipVeteran = ownershipVeteran;
	}

	/**
	 * @return the annualSales
	 */
	public Double getAnnualSales()
	{
		return annualSales;
	}

	/**
	 * @param annualSales the annualSales to set
	 */
	public void setAnnualSales(Double annualSales)
	{
		this.annualSales = annualSales;
	}

	/**
	 * @return the fiscalYearEnd
	 */
	public Integer getFiscalYearEnd()
	{
		return fiscalYearEnd;
	}

	/**
	 * @param fiscalYearEnd the fiscalYearEnd to set
	 */
	public void setFiscalYearEnd(Integer fiscalYearEnd)
	{
		this.fiscalYearEnd = fiscalYearEnd;
	}

	/**
	 * @return the stockExchange
	 */
	public String getStockExchange()
	{
		return stockExchange;
	}

	/**
	 * @param stockExchange the stockExchange to set
	 */
	public void setStockExchange(String stockExchange)
	{
		this.stockExchange = stockExchange;
	}

	/**
	 * @return the stockSymbol
	 */
	public String getStockSymbol()
	{
		return stockSymbol;
	}

	/**
	 * @param stocksymbol the stockSymbol to set
	 */
	public void setStockSymbol(String stockSymbol)
	{
		this.stockSymbol = stockSymbol;
	}

	/**
	 * @return the taxExmpt
	 */
	public Boolean getTaxExmpt()
	{
		return taxExmpt;
	}

	/**
	 * @param taxExmpt the taxExmpt to set
	 */
	public void setTaxExmpt(Boolean taxExmpt)
	{
		this.taxExmpt = taxExmpt;
	}

	/**
	 * @return the w9Name
	 */
	public String getW9Name()
	{
		return w9Name;
	}

	/**
	 * @param w9Name the w9Name to set
	 */
	public void setW9Name(String w9Name)
	{
		this.w9Name = w9Name;
	}

	/**
	 * @return the w9BusinessName
	 */
	public String getW9BusinessName()
	{
		return w9BusinessName;
	}

	/**
	 * @param w9BusinessName the w9BusinessName to set
	 */
	public void setW9BusinessName(String w9BusinessName)
	{
		this.w9BusinessName = w9BusinessName;
	}

    /**
     * @return the linkingStatus
     */
    public String getLinkingStatus()
    {
        return linkingStatus;
    }

    /**
     * @param linkingStatus the linkingStatus to set
     */
    public void setLinkingStatus(String linkingStatus)
    {
        this.linkingStatus = linkingStatus;
    }

    public Boolean getApproved()
    {
        return approved;
    }

    public void setApproved(Boolean approved)
    {
        this.approved = approved;
    }

    public Long getDuplicateSupplierId()
    {
        return duplicateSupplierId;
    }

    public void setDuplicateSupplierId(Long duplicateSupplierId)
    {
        this.duplicateSupplierId = duplicateSupplierId;
    }

    public Boolean getPrimarySource()
    {
        return primarySource;
    }

    public void setPrimarySource(Boolean isPrimarySource)
    {
        this.primarySource = isPrimarySource;
    }
   
}
