package com.emptoris.vsm.sync.dto;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@SuppressWarnings("serial")
public class UserDTO implements Serializable
{
    public static enum UserType {
        User, Contact
    }

    public static enum PhoneType {
        Main, Alternate, Fax, Mobile, Pager
    }

    public static enum KindOfAuth {
        Internal, External
    }
    
    private String uuId;
    private Boolean deleted = Boolean.FALSE;
    private Boolean system; // ECM, ESP users get super-user privileges
    private Boolean external;
    private String type;
    private String userName;
    private String salutation; // SLM
    private String firstName;
    private String middleName; // ECM, ESP
    private String lastName;
    private String title; // ECM, ESP
    private String businessTitle; // SLM
    private String emailAddress;
    private String alternateEmail;
    private String managerUUID;
    private String displayName;
    
    private String timezone;
    private String locale;
    private String dateFormat;
    private String numberFormat;
    private String currencyCode;
    private String notes;
    private List<Product> products;
    private List<Address> addresses;
    private List<Phone> phones;

    private String identifier;
    private String externalSourceId;
    private String externalSourceName;
    private Boolean enableNotification;
    private String createdBy;
    private Date createdOn;
    private String updatedBy;
    private Date updatedOn;

    private List<String> linkedCategories;

    private String remoteId;
    
    private String kindOfAuth;

    
    public String getUuId()
    {
        return uuId;
    }

    public void setUuId(String uuId)
    {
        this.uuId = uuId;
    }

    public Boolean getDeleted()
    {
        return deleted;
    }

    public void setDeleted(Boolean deleted)
    {
        this.deleted = deleted;
    }

    public Boolean getSystem()
    {
        return system;
    }

    public void setSystem(Boolean system)
    {
        this.system = system;
    }

    public Boolean getExternal()
    {
        return external;
    }

    public void setExternal(Boolean external)
    {
        this.external = external;
    }

    public String getType()
    {
        return type;
    }

    public void setType(String type)
    {
        this.type = type;
    }

    public String getUserName()
    {
        return userName;
    }

    public void setUserName(String userName)
    {
        this.userName = userName;
    }

    public String getBusinessTitle()
    {
        return businessTitle;
    }

    public void setBusinessTitle(String businessTitle)
    {
        this.businessTitle = businessTitle;
    }

    public String getFirstName()
    {
        return firstName;
    }

    public void setFirstName(String firstName)
    {
        this.firstName = firstName;
    }

    public String getLastName()
    {
        return lastName;
    }

    public void setLastName(String lastName)
    {
        this.lastName = lastName;
    }

    /*
    	public String getSuffix() {
    		return suffix;
    	}
    	public void setSuffix(String suffix) {
    		this.suffix = suffix;
    	}
    	public Date getDateOfBirth() {
    		return dateOfBirth;
    	}
    	public void setDateOfBirth(Date dateOfBirth) {
    		this.dateOfBirth = dateOfBirth;
    	}
    	public String getGender() {
    		return gender;
    	}
    	public void setGender(String gender) {
    		this.gender = gender;
    	}
    */
    public String getEmailAddress()
    {
        return emailAddress;
    }

    public void setEmailAddress(String emailAddress)
    {
        this.emailAddress = emailAddress;
    }

    public String getTimezone()
    {
        return timezone;
    }

    public void setTimezone(String timezone)
    {
        this.timezone = timezone;
    }

    public String getLocale()
    {
        return locale;
    }

    public void setLocale(String locale)
    {
        this.locale = locale;
    }

    public String getDateFormat()
    {
        return dateFormat;
    }

    public void setDateFormat(String dateFormat)
    {
        this.dateFormat = dateFormat;
    }

    public String getNumberFormat()
    {
        return numberFormat;
    }

    public void setNumberFormat(String numberFormat)
    {
        this.numberFormat = numberFormat;
    }

    public String getCurrencyCode()
    {
        return currencyCode;
    }

    public void setCurrencyCode(String currencyCode)
    {
        this.currencyCode = currencyCode;
    }

    public String getNotes()
    {
        return notes;
    }

    public void setNotes(String notes)
    {
        this.notes = notes;
    }

    public String getSalutation()
    {
        return salutation;
    }

    public void setSalutation(String salutation)
    {
        this.salutation = salutation;
    }

    public String getMiddleName()
    {
        return middleName;
    }

    public void setMiddleName(String middleName)
    {
        this.middleName = middleName;
    }

    public String getTitle()
    {
        return title;
    }

    public void setTitle(String title)
    {
        this.title = title;
    }

    public List<Product> getProducts()
    {
        return products;
    }

    public void setProducts(List<Product> products)
    {
        this.products = products;
    }

    public void addProduct(Product product)
    {
        if (products == null)
        {
            products = new ArrayList<Product>();
        }
        products.add(product);
    }

    public List<Address> getAddresses()
    {
        return addresses;
    }

    public void setAddresses(List<Address> addresses)
    {
        this.addresses = addresses;
    }

    public void addAddress(Address address)
    {
        if (addresses == null)
        {
            addresses = new ArrayList<Address>();
        }
        addresses.add(address);
    }

    public List<Phone> getPhones()
    {
        return phones;
    }

    public void setPhones(List<Phone> phones)
    {
        this.phones = phones;
    }

    public void addPhone(Phone phone)
    {
        if (phones == null)
        {
            phones = new ArrayList<Phone>();
        }
        phones.add(phone);
    }

    /*
        public List<BusinessUnit> getBusinessUnits() {
            return businessUnits;
        }
        public void setBusinessUnits(List<BusinessUnit> businessUnits) {
            this.businessUnits = businessUnits;
        }
        public void addBusinessUnit(BusinessUnit businessUnit) {
            if (businessUnits == null) {
                businessUnits = new ArrayList<BusinessUnit>();
            }
            businessUnits.add(businessUnit);
        }
        public List<Alias> getAliases() {
            return aliases;
        }
        public void setAliases(List<Alias> aliases) {
            this.aliases = aliases;
        }
        public void addAlias(Alias alias) {
            if (aliases == null) {
                aliases = new ArrayList<Alias>();
            }
            aliases.add(alias);
        }
    */

    public String getIdentifier()
    {
        return identifier;
    }

    public void setIdentifier(String identifier)
    {
        this.identifier = identifier;
    }

    public String getExternalSourceId()
    {
        return externalSourceId;
    }

    public void setExternalSourceId(String externalSourceId)
    {
        this.externalSourceId = externalSourceId;
    }

    public String getExternalSourceName()
    {
        return externalSourceName;
    }

    public void setExternalSourceName(String externalSourceName)
    {
        this.externalSourceName = externalSourceName;
    }

    public Boolean getEnableNotification()
    {
        return enableNotification;
    }

    public void setEnableNotification(Boolean enableNotification)
    {
        this.enableNotification = enableNotification;
    }

    public String getCreatedBy()
    {
        return createdBy;
    }

    public void setCreatedBy(String createdBy)
    {
        this.createdBy = createdBy;
    }

    public Date getCreatedOn()
    {
        return createdOn;
    }

    public void setCreatedOn(Date createdOn)
    {
        this.createdOn = createdOn;
    }

    public String getUpdatedBy()
    {
        return updatedBy;
    }

    public void setUpdatedBy(String updatedBy)
    {
        this.updatedBy = updatedBy;
    }

    public Date getUpdatedOn()
    {
        return updatedOn;
    }

    public void setUpdatedOn(Date updatedOn)
    {
        this.updatedOn = updatedOn;
    }

    public List<String> getLinkedCategories()
    {
        return linkedCategories;
    }

    public void setLinkedCategories(List<String> linkedCategories)
    {
        this.linkedCategories = linkedCategories;
    }

    public String getAlternateEmail()
    {
        return alternateEmail;
    }

    public void setAlternateEmail(String alternateEmail)
    {
        this.alternateEmail = alternateEmail;
    }

    public String getManagerUUID()
    {
        return managerUUID;
    }

    public void setManagerUUID(String managerUUID)
    {
        this.managerUUID = managerUUID;
    }

    public String getDisplayName()
    {
        return displayName;
    }

    public void setDisplayName(String displayName)
    {
        this.displayName = displayName;
    }

    public String getRemoteId()
    {
        return remoteId;
    }

    public void setRemoteId(String remoteId)
    {
        this.remoteId = remoteId;
    }

    public String getKindOfAuth()
    {
        return kindOfAuth;
    }

    public void setKindOfAuth(String kindOfAuth)
    {
        this.kindOfAuth = kindOfAuth;
    }
}
