#######################################################
# wsadmin script to deploy Emptoris Contract Management
#######################################################

########### Start Imports ###########
from install.GetProfilePath import GetProfilePath
from install.WASService import WASService

from util.Boolean import * 
import util.utility as util

import was_objs.import_was as wasScript
execfile(wasScript.__file__)
########### End Imports ###########

########### Start Variable Definitions ###########
wasHome = args['wasHome']
profileName = args['profileName']
serverName = args['serverName']
nodeName = args['nodeName']
cellName = args['cellName']
debugMode = args['debug']
debugPort = args['debugPort']
suiteApps = None


########### End Variable Definitions ###########

# Make sure the WAS profile exists
profilePath = GetProfilePath(wasHome).getProfilePath(profileName)
if profilePath is None:
    raise Exception('Could not find target profile path for profile [' + profileName + ']') 

try:
    print "Configuring IBM Emptoris Strategic Supply Management..."

    ########### Create a new server ###########
    svr = server.Server(serverName, nodeName, cellName)
    svr.setPortSet(args['portSet'])
    svr.configure()
    
    
    oracleDatabase = "Oracle"
    db2Database = "DB2"
    if args['rdbmsVendor'] == oracleDatabase :
        varName = "ORACLE_JDBC_DRIVER_PATH"
    else:
        varName = "DB2_JCC_DRIVER_PATH"
    newVarValue = args['jdbcDriverPath']
    nodeConfigId = AdminConfig.getid('/Cell:' + cellName + '/Node:' + nodeName + '/')
    varSubstitutions = AdminConfig.list("VariableSubstitutionEntry",nodeConfigId).splitlines()
    for varSubst in varSubstitutions:
        getVarName = AdminConfig.showAttribute(varSubst, "symbolicName")
        if getVarName == varName:
            AdminConfig.modify(varSubst,[["value", newVarValue]])
            break
    print 'database = ' + oracleDatabase
    print  'url = '+ args['dataSourceUrl']
    
    ########### Start JVM Configuration ###########
        
    jvmconfig = jvm.JavaVirtualMachine(svr)
    jvmconfig.setInitialHeapSize(args['javaHeap'])
    jvmconfig.setMaximumHeapSize(args['javaHeap'])
    jvmconfig.setClasspath([args['gatewayClasspath']])
    jvmconfig.setDebugMode(debugMode)
    jvmconfig.setDebugArgs("-agentlib:jdwp=transport=dt_socket,server=y,suspend=n,address=" + str(debugPort))
    
    jvmconfig.addSystemProperty('shared.code.install.dir', args['shared.code.install.dir'], 'SSM Shared Installation Directory')
    jvmconfig.addSystemProperty('file.encoding','UTF8','File default encoding')
    jvmconfig.addSystemProperty('rivermine.registries','com.rivermine.app.gateway.GatewayRegistry','SSM Application Registry')
    jvmconfig.addSystemProperty('rivermine.mode','prod','SSM Application start mode')
    jvmconfig.addSystemProperty('rivermine.server.port',str(args['rivermineServerPort']),'SSM Application server port')
    jvmconfig.addSystemProperty('rivermine.home',args['rivermineHome'],'SSM Application home location')
    jvmconfig.addSystemProperty('default.language',args['defaultLanguage'],'Category default language')
    jvmconfig.addSystemProperty('supplier.discoveryProviders','','Supplier discovery providers')
    jvmconfig.addSystemProperty('hibernate.wxs.catalog.service.bootstrap.port',str(args['wxsCatalogPort']),'Hibernate eXtreme Scale bootstap port number')    
    jvmconfig.addSystemProperty('com.ibm.ws.amm.scan.context.filter.archives','activation.jar,adf.jar,AdminConsoleFramework-1.4.jar,antlr-2.7.6.jar,aopalliance-1.0.jar,axis-ant.jar,axis.jar,bsh-2.0b4.jar,commons-collections-3.2.jar,commons-discovery-0.2.jar,commons-fileupload-1.0.jar,contract-client.jar,dom4j-1.6.1.jar,echo2consultas.jar,Echo2_App.jar,Echo2_Chart_App.jar,Echo2_Chart_WebContainer.jar,Echo2_Contrib-2.0.jar,Echo2_Extras_App.jar,Echo2_Extras_WebContainer.jar,Echo2_FileTransfer_App.jar,Echo2_FileTransfer_WebContainer.jar,Echo2_WebContainer.jar,Echo2_WebRender.jar,echopointng-2.1.0rc5.jar,EmptorisDataSyncClient-1.4.4.jar,EmptorisDataSyncCommon-1.4.4.jar,EmptorisDataSyncServer-1.4.5.jar,hibernate3.jar,httpclient-4.0.1.jar,httpcore-4.0.1.jar,iText-2.1.3.jar,iTextAsian.jar,javassist-3.9.0.GA.jar,javax.persistence_2.0.3.v201010191057.jar,jaxrpc.jar,jcifs-1.2.17.jar,jcl-over-slf4j-1.6.1.jar,jcommon-1.0.15.jar,jfreechart-1.0.12.jar,json-rpc-1.0.jar,jta-1.1.jar,liquibase.jar,log4j-1.2.14.jar,log4jdbc3-1.1.jar,lots.jar,lucene-core-3.6.2.jar,lucene-highlighter-3.6.2.jar,lucene-memory-3.6.2.jar,mail.jar,mime-util-2.1.3.jar,odmg-3.0.jar,opencsv-1.8.jar,opensaml-2.1.0.jar,org.eclipse.emf.common_2.2.0.v200605151820.jar,org.eclipse.emf.ecore.xmi_2.2.0.v200605151820.jar,org.eclipse.emf.ecore_2.2.0.v200605151820.jar,org.springframework.aop-3.0.5.RELEASE.jar,org.springframework.asm-3.0.5.RELEASE.jar,org.springframework.aspects-3.0.5.RELEASE.jar,org.springframework.beans-3.0.5.RELEASE.jar,org.springframework.context-3.0.5.RELEASE.jar,org.springframework.context.support-3.0.5.RELEASE.jar,org.springframework.core-3.0.5.RELEASE.jar,org.springframework.expression-3.0.5.RELEASE.jar,org.springframework.transaction-3.0.5.RELEASE.jar,org.springframework.web-3.0.5.RELEASE.jar,p6spy.jar-1.3.jar,platform-1.3.jar,platform-src-1.3.jar,poi-3.9-20121203.jar,poi-ooxml-3.9-20121203.jar,poi-ooxml-schemas-3.9-20121203.jar,saaj.jar,secondstring-20120504.jar,security-0.0.2.jar,sftp.jar,slf4j-api-1.6.1.jar,slf4j-log4j12-1.6.1.jar,tucana-20060720.jar,vsm-wsclient-1.2.6.1.jar,vsmclient-1.2.6.1.jar,webservices-client.jar,wsdl4j-1.5.1.jar,xBaseJ.jar,xml-security-1.4.1.jar,xmlbeans-2.3.0.jar,xmldsig.jar,xmltooling-1.0.1.jar,xpp3_min-1.1.4c.jar,xstream-1.3.1.jar,YourKitController-8.0.12.jar','SSM Webservices annotation scan filter')
    
    jvmconfig.addSystemProperty('rivermine.smtp.server',args['smtpServer'],'SMTP Mail Server')
    if 'mailSender' in args.keys() and args['mailSender'] is not None and args['mailSender'] != "":
        jvmconfig.addSystemProperty('rivermine.mail.sender',args['mailSender'],'Mail Sender')
    
    if args['antivirusEnabled'] == 'true':
        jvmconfig.addSystemProperty('rivermine.antivirus.server.host',args['antivirusServerHost'],'Antivirus Server host name')
        jvmconfig.addSystemProperty('rivermine.antivirus.server.port',str(args['antivirusServerPort']),'Antivirus Server port number')

    if 'defaultCurrency' in args.keys() and args['defaultCurrency'] is not None and args['defaultCurrency'] != "":
        jvmconfig.addSystemProperty('rivermine.default.currency',args['defaultCurrency'],'Default Currency')

    doEnableAccess = 'enableSqlAndBeanshellAccess' in args.keys() and args['enableSqlAndBeanshellAccess'] is not None and args['enableSqlAndBeanshellAccess'] != "" and args['enableSqlAndBeanshellAccess']
    jvmconfig.addSystemProperty('rivermine.enablesqlaccess ',doEnableAccess,'Enable SQL And Beanshell Access')
    
    jvmconfig.addSystemProperty('ssm.web.url',args['ssm.web.protocol']+ '://'+ args['ssm.web.host']+ ':'+ str(args['ssm.web.port']) + '/emptoris','SSM Application URL')

    suiteApps = []
    if args['pgm.enabled'] == 'true':
        suiteApps.append('PGM')
        
    if args['suite.apps.slm'] == 'SLM':
        suiteApps.append('SLM')
        jvmconfig.addSystemProperty('slm.web.url',args['slm.web.protocol']+ '://'+ args['slm.web.host']+ ':'+ str(args['slm.web.port'])+ '/srm-app','SLM Application URL')
        
    if args['suite.apps.esp'] == 'ESP':
        suiteApps.append('ESP')
        jvmconfig.addSystemProperty('esp.web.url',args['esp.web.protocol']+ '://'+ args['esp.web.host']+ ':'+ str(args['esp.web.port']),'Sourcing Application URL')
        
    if args['suite.apps.ecm'] == 'ECM':
        suiteApps.append('ECM')
        jvmconfig.addSystemProperty('ecm.web.url',args['ecm.web.protocol']+ '://'+ args['ecm.web.host']+ ':'+ str(args['ecm.web.port'])+ '/dicarta','Contract Management Application URL')
        
    if args['suite.apps.spend'] == 'Spend':
        suiteApps.append('Spend')
        jvmconfig.addSystemProperty('spend.web.url',args['spend.web.protocol']+ '://'+ args['spend.web.host']+ ':'+ str(args['spend.web.port'])+ '/expensemap', 'Spend Application URL')
        
    if suiteApps is not None and len(suiteApps) > 0:
        jvmconfig.addSystemProperty('suite.apps', ','.join(suiteApps), 'Enabled Suite Applications')        
        
    jvmconfig.configure()
    ########### End JVM Configuration ###########
    
    ########### Start DataSource Configuration ###########
    auth = jaasAuthData.JAASAuthData()
    auth.setAlias(args['dataSourceName'])
    auth.setDescription("Credentials for DefaultDS")
    auth.setUserId(args['dataSourceUserId'])
    auth.setPassword(args['dataSourcePassword'])
    auth.setServer(svr)
    auth.configure()
        
    jdbcP = jdbcProvider.JDBCProvider()
    jdbcP.setName(args['dataSourceName'])
    jdbcP.setVendor(args['rdbmsVendor'])
    jdbcP.setClasspath(args['jdbcDriverLocation'])
    jdbcP.setServer(svr)
    jdbcP.configure()

    ds = dataSource.DataSource()
    ds.setName(args['dataSourceName'])
    ds.setCategory(args['dataSourceName'])
    ds.setJndiName(args['dataSourceJndiName'])
    if 'dataSourceUrl' in args.keys() and args['rdbmsVendor'] == oracleDatabase :
        ds.setURL(args['dataSourceUrl'])
    else:
        ds.setResourceAttribute('databaseName', args['databaseServicename'])
        ds.setResourceAttribute('driverType', 4, 'java.lang.Integer')
        ds.setResourceAttribute('serverName', args['databaseIP'])
        ds.setResourceAttribute('portNumber', args['databasePort'], 'java.lang.Integer')
    ds.setAuthDataAlias(auth)
    ds.setServer(svr)
    ds.setJdbcProvider(jdbcP)
    ds.configure()
    datasourceConfigId = ds.getConfigId()
    connectionPoolId = AdminConfig.list('ConnectionPool', datasourceConfigId)
    AdminConfig.modify(connectionPoolId, '[[maxConnections "25"] [minConnections "5"]]')
    if args['rdbmsVendor'] == db2Database :
        ds.setResourceAttribute('currentSchema', args['db2Schema'])
        ds.setResourceAttribute('currentFunctionPath', args['db2Schema'])
        ds.configure()
    
    ########### End DataSource Configuration ###########
    
    ########### Start Library Configuration ###########
    sharedLib = library.Library("Library")
    sharedLib.setDescription('Shared library for Gateway')
    sharedLib.setScope(svr.getCellContainmentPathId())
    sharedLib.setClassPath(args['appLibLocation'])
    sharedLib.configure()
    ########### End Library Configuration ###########

    ########### Start login entry ###########
    gatewayLoginEntry = jaasLoginEntry.JAASLoginEntry()
    gatewayLoginEntry.setLoginEntryAlias('Gateway')
    gatewayLoginEntry.setLoginType('application')

    
    
    
    
    # SSOClientLoginModule
    #ssoLoginModule = jaasAppLoginModule.JAASApplicationLoginModule()
    #ssoLoginModule.setLoginEntryAlias('Sso')
    #ssoLoginModule.setLoginModule('com.emptoris.framework.remote.client.sso.SSOClientLoginModule')
    #ssoLoginModule.setAuthStrategy('REQUIRED')
    #ssoLoginModule.addCustomProperty('debug','false')
    
    


    ########### Start Application Deployment ###########
    domainName = ""
    if 'domainName' in args.keys() and args['domainName'] is not None:
        domainName = args['domainName']
    
    inst = installer.Installer(args['appFileLocation'], args['installerPropertiesLocation'])
    inst.setServer(svr)
    
    inst.setMapSharedLibForMod([[".*", 'META-INF/application.xml', sharedLib.getName()]])
    inst.setMapResRefToEJB([[".*", "", 'emptoris.war,WEB-INF/web.xml', 'jdbc/RivermineDB', 'javax.sql.DataSource', ds.getJndiName(), "", "", "", ]])
    inst.setProcessEmbeddedConfig(false)
    inst.setNoprocessEmbeddedConfig(true)
    inst.setCookieDomain(domainName)
    
    if 'overlayPath' in args.keys() and args['overlayPath'] is not None and not args['overlayPath'] == '':
        inst.setOverlay(args['overlayPath'])
    
    # Check if we need to remove old installation
    # This is needed if the version is prior to 10.0.1.0 when we started packaging an ear file 
    # Get the version info of the already-installed application
    print "Getting the installed version."
    inst.setAppname('emptoris')
    if inst.isInstalled():
        print "emptoris is installed"
        installedBuildVersion = AdminApp.view('emptoris', '-buildVersion')
        installedBuildVersion = installedBuildVersion.split(':', 1)[1].strip()
        print "Current build is " + installedBuildVersion
		
        if installedBuildVersion == "" or installedBuildVersion is None or installedBuildVersion == 'Unknown':
            print "Could not determine current build version.  Assuming pre 10.0.1.0 and uninstall is needed."
            inst.uninstall()


    inst.configure()
    print "Saving changes..."
    AdminConfig.save()
    print "Changes saved."
    ########### End Application Deployment ###########
except Exception, e:
    print "Server configuration failed.  Rolling back changes."
    AdminConfig.reset()
    raise # Re-throw to terminate the script
    
    
